@@ -5,6 +5,10 @@ import hashlib
 import json
 import sqlite3
 import os
+import requests
+import logging
+
+log = logging.getLogger(__name__)
 
 database = peewee.SqliteDatabase(DATABASE)
 
@@ -25,12 +29,25 @@ class BaseModel(peewee.Model):
     class Meta:
         database = database
 
-    @classmethod
-    def create(cls, **attributes):
-        return super(BaseModel, cls).create(**attributes)
+
+class SyncedModel(peewee.Model):
+    class Meta:
+        database = database
 
 
-class Backups(BaseModel):
+class History(BaseModel):
+    """History for sync."""
+    data = JsonField()
+    ts = peewee.IntegerField(index=True)
+    action = peewee.CharField(index=True)
+    model = peewee.CharField(index=True)
+    pk = peewee.CharField(index=True)
+
+    class Meta:
+        db_table = 'history'
+
+
+class Backups(SyncedModel):
     """Backups Model."""
     backend = peewee.CharField(index=True)
     backend_hash = peewee.CharField(index=True, null=True)
@@ -43,6 +60,9 @@ class Backups(BaseModel):
     stored_filename = peewee.TextField(index=True, unique=True)
     tags = peewee.CharField()
 
+    def __repr__(self):
+        return "<Backup: {0}>".format(self._data.get("stored_filename"))
+
     @classmethod
     def match_filename(cls, filename, destination, **kwargs):
         conf = config
@@ -142,6 +162,9 @@ class Backups(BaseModel):
     class Meta:
         db_table = 'backups'
 
+    class Sync:
+        pk = 'stored_filename'
+
 
 class Config(BaseModel):
     """key => value config store."""
@@ -167,7 +190,7 @@ class Config(BaseModel):
         db_table = 'config'
 
 
-class Inventory(BaseModel):
+class Inventory(SyncedModel):
     """Filename => archive_id mapping for glacier archives."""
     archive_id = peewee.CharField(index=True, unique=True)
     filename = peewee.CharField(index=True)
@@ -179,8 +202,11 @@ class Inventory(BaseModel):
     class Meta:
         db_table = 'inventory'
 
+    class Sync:
+        pk = 'filename'
 
-class Jobs(BaseModel):
+
+class Jobs(SyncedModel):
     """filename => job_id mapping for glacier archives."""
     filename = peewee.CharField(index=True)
     job_id = peewee.CharField()
@@ -222,7 +248,7 @@ class Jobs(BaseModel):
         db_table = 'jobs'
 
 
-for table in [Backups, Jobs, Inventory, Config]:
+for table in [Backups, Jobs, Inventory, Config, History]:
     if not table.table_exists():
         table.create_table()
 
